@@ -1685,7 +1685,7 @@ submit -p @@file=globnat:indeck* sim.exe @@file
          reHeaderExpr = re.compile(headerExpr)
          if os.path.isfile(csvDataFile):
             try:
-               fpCSVData = open(csvDataFile,'rt')
+               fpCSVData = open(csvDataFile,'r')
                try:
                   csvReader = csv.reader(fpCSVData)
                   try:
@@ -1736,7 +1736,7 @@ submit -p @@file=globnat:indeck* sim.exe @@file
    def __getNextCSVDataCombination(self):
       csvDataFile = self.commandOptions.csvData[0]
       try:
-         fpCSV = open(csvDataFile,'rt')
+         fpCSV = open(csvDataFile,'r')
          try:
             csvReader = csv.reader(fpCSV)
             if self.csvDataHasHeader:
@@ -1902,7 +1902,7 @@ submit -p @@file=globnat:indeck* sim.exe @@file
    def getNextParameterCombinationFromCSV(self,
                                           csvPath):
       try:
-         fpCSV = open(csvPath,'rt')
+         fpCSV = open(csvPath,'r')
          try:
             csvReader = csv.reader(CommentedFile(fpCSV))
             parameterNames = next(csvReader)
